#!/usr/bin/python
# -*- coding: utf-8 -*-
#
# This program is free software; you can redistribute it and/or modify
# it under the terms of the GNU General Public License as published by
# the Free Software Foundation; either version 2 of the License, or
# (at your option) any later version.
# 
# This program is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU Library General Public License for more details.
# 
# You should have received a copy of the GNU General Public License
# along with this program; if not, write to the Free Software
# Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.

import sys
import gtk
import consts
import msgBox
import dlgTerm
import os.path
import dlgAbout
import gtk.glade

# ---======---
# Main class : create a window to interact with the user
# ---======---
class Main :

    # === Constructor ===
    def __init__(self, argv) :
        # Create the window, retrieve widgets
        self.wTree       = gtk.glade.XML(consts.dirRes + 'win-main.glade')
        self.window      = self.wTree.get_widget('win-main')
        self.dlgTerm     = self.wTree.get_widget('dlg-term')
        self.filechooser = self.wTree.get_widget('filechooser')
        self.radioRepair = self.wTree.get_widget('radio-repair')
        self.radioVerify = self.wTree.get_widget('radio-verify')

        # Connect events
        dic_events = {
            'onWinDestroy' : gtk.main_quit,
            'onBtnQuit'    : gtk.main_quit,
            'onMnuQuit'    : gtk.main_quit,
            'onMnuAbout'   : self.onMnuAbout,
            'onBtnGo'      : self.onBtnGo,
        }
        self.wTree.signal_autoconnect(dic_events)

        # Prepare the file chooser
        self.filechooser.set_current_folder(os.path.expanduser('~'))
        filter = gtk.FileFilter()
        filter.add_pattern('*.par2')
        filter.add_pattern('*.PAR2')
        self.filechooser.set_filter(filter)

        # If a file was given on the command line, select it
        if len(argv) > 1 :
            self.filechooser.set_filename(argv[1])

        # Prepare the window and show it
        self.window.set_title(consts.appName)
        self.window.show()
        gtk.main()

    # == Display the about dialog box ===
    def onMnuAbout(self, widget) :
        dlgAbout.getInstance(self.window).show()

    # === 'Go' button was clicked ===
    def onBtnGo(self, widget) :
        # Ensure that a file has been selected
        if self.filechooser.get_filename() == None :
            msgBox.error(self.window, 'You must first select a par2 file!')
            return
        # Construct the command line to use
        if self.radioRepair.get_active() :
            cmdLine = 'par2 r -q "' + self.filechooser.get_filename() + '"'
        elif self.radioVerify.get_active() :
            cmdLine = 'par2 v -q "' + self.filechooser.get_filename() + '"'
        else :
            msgBox.error(self.window, 'No action selected!')
            return
        # Execute this command
        dlgTerm.getInstance(self.window).show(cmdLine)


# ---======---
# Entry point
# ---======---
if __name__ != '__main__' :
    print 'Error : Not a module'
    sys.exit()

# Create the main window
Main(sys.argv)
